@@ -1694,6 +1694,29 @@ int run_server(t_settings *settings) {
 	init_command_module();
 #endif
 
+	/* Redirecting I/O to /dev/null
+	 */
+	if (close(STDIN_FILENO) == -1) {
+		fprintf(stderr, "Warning: error closing STDIN\n");
+	} else if (open("/dev/null", O_RDONLY) == -1) {
+		fprintf(stderr, "Error redirecting stdin\n");
+		return EXIT_FAILURE;
+	}
+#ifndef DEBUG
+	if (close(STDOUT_FILENO) == -1) {
+		fprintf(stderr, "Warning: error closing STDOUT\n");
+	} else if (open("/dev/null", O_WRONLY) == -1) {
+		fprintf(stderr, "Error redirecting stdout\n");
+		return EXIT_FAILURE;
+	}
+	if (close(STDERR_FILENO) == -1) {
+		fprintf(stderr, "Warning: error closing STDERR\n");
+	} else if (open("/dev/null", O_WRONLY) == -1) {
+		log_string(config->system_logfile, "Error redirecting stderr\n");
+		return EXIT_FAILURE;
+	}
+#endif
+
 	log_string(config->system_logfile, "Hiawatha v"VERSION" started");
 
 	do {
