@@ -143,19 +143,21 @@ bool valid_uri(char *uri) {
 	if (*(uri + strlen(uri) - 1) == '.') {
 		return false;
 	}
+
+	if (strstr(uri, "\\.") != NULL) {
+		return false;
+	}
 #endif
 
-	do {
-		if (*(uri + 1) == '.') {
-			if ((*uri == '.') || (*uri == '/')) {
-				return false;
-			}
-		}
-		if ((*uri < 32) || (*uri > 126)) {
+	if (strstr(uri, "/.") != NULL) {
+		return false;
+	}
+
+	while (*(++uri) != '\0') {
+		if (*uri < 32) {
 			return false;
 		}
-		uri++;
-	} while (*uri != '\0');
+	}
 
 	return true;
 }
