@@ -210,7 +210,7 @@ int send_header(t_session *session, int code) {
 		return -1;
 	} else if (send_buffer(session, hs_eol, 2) == -1) {
 		return -1;
-	} else if ((session->cgi_type == none) && (session->uri_is_dir == false)) {
+	} else if ((session->cgi_type == no_cgi) && (session->uri_is_dir == false)) {
 		if (send_buffer(session, hs_range, 22) == -1) {
 			return -1;
 		}
@@ -409,7 +409,7 @@ int send_code(t_session *session, int code) {
 		return -1;
 	} else if (send_buffer(session, "text/html\r\n\r\n", 13) == -1) {
 		return -1;
-	} else if (session->head_request) {
+	} else if (session->request_method == HEAD) {
 		return 0;
 	} else if (send_buffer(session, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n", 91) == -1) {
 		return -1;
