@@ -24,17 +24,15 @@ int new_client_id = 0;
 /* Set the entries in a session-record to the default values.
  */
 static void clear_session(t_session *session) {
-	session->head_request = false;
-	session->cgi_type = none;
+	session->cgi_type = no_cgi;
 	session->cgi_handler = NULL;
 	session->fcgi_server = NULL;
 	session->method = NULL;
 	session->uri = NULL;
 	session->uri_len = 0;
 	session->uri_is_dir = false;
-#ifdef HAVE_REWRITE
 	session->request_uri = NULL;
-#endif
+	session->request_method = unknown;
 	session->accept_gzip = false;
 	session->encode_gzip = false;
 	session->path_info = NULL;
@@ -60,6 +58,7 @@ static void clear_session(t_session *session) {
 	session->bytecounter = 0;
 	session->part_of_dirspeed = false;
 	session->remote_user = NULL;
+	session->http_auth = no_auth;
 	session->directory = NULL;
 	session->handling_error = false;
 	session->reason_for_403 = "";
@@ -69,7 +68,6 @@ static void clear_session(t_session *session) {
 	session->return_code = 200;
 	session->error_code = -1;
 	session->tempdata = NULL;
-	session->put_method = false;
 	session->uploaded_file = NULL;
 	session->uploaded_size = 0;
 #ifdef DEBUG
@@ -109,9 +107,7 @@ void reset_session(t_session *session) {
 	sfree(session->local_user);
 	sfree(session->remote_user);
 	sfree(session->path_info);
-#ifdef HAVE_REWRITE
 	sfree(session->request_uri);
-#endif
 	if (session->uploaded_file != NULL) {
 		unlink(session->uploaded_file);
 		free(session->uploaded_file);
@@ -160,6 +156,42 @@ void destroy_session(t_session *session) {
 	sfree(session->request);
 }
 
+/* Determine the request method
+ */
+void determine_request_method(t_session *session) {
+	if (strncmp(session->request, "GET ", 4) == 0) {
+		session->request_method = GET;
+	} else if (strncmp(session->request, "POST ", 5) == 0) {
+		session->request_method = POST;
+	} else if (strncmp(session->request, "HEAD ", 5) == 0) {
+		session->request_method = HEAD;
+	} else if (strncmp(session->request, "OPTIONS ", 8) == 0) {
+		session->request_method = OPTIONS;
+	} else if (strncmp(session->request, "TRACE ", 6) == 0) {
+		session->request_method = TRACE;
+	} else if (strncmp(session->request, "PUT ", 4) == 0) {
+		session->request_method = PUT;
+	} else if (strncmp(session->request, "DELETE ", 7) == 0) {
+		session->request_method = DELETE;
+	} else if (strncmp(session->request, "CONNECT ", 8) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "PROPFIND ", 9) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "PROPPATCH ", 10) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "MKCOL ", 6) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "COPY ", 5) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "MOVE ", 5) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "LOCK ", 5) == 0) {
+		session->request_method = unsupported;
+	} else if (strncmp(session->request, "UNLOCK ", 7) == 0) {
+		session->request_method = unsupported;
+	}
+}
+
 /* Parse the HTTP headerfields from the received request.
  */
 t_headerfield *parse_headerfields(char *line) {
