@@ -12,7 +12,8 @@
 #define MAX_CHILD_ID        30000
 #define OUTPUT_BUFFER_SIZE      2 * KILOBYTE
 
-typedef enum { none, program, script, fastcgi} t_cgi_type;
+typedef enum { no_cgi, program, script, fastcgi} t_cgi_type;
+typedef enum { unknown, GET, POST, HEAD, OPTIONS, TRACE, PUT, DELETE, unsupported } t_req_method;
 #ifdef HAVE_SSL
 typedef enum { missing_slash, require_ssl } t_cause_of_301;
 #endif
@@ -31,7 +32,6 @@ typedef struct type_session {
 	int             client_socket;
 	t_binding       *binding;
 	bool            socket_open;
-	bool            head_request;
 	bool            keep_alive;
 	int             kept_alive;
 	t_cgi_type      cgi_type;
@@ -39,9 +39,8 @@ typedef struct type_session {
 	t_fcgi_server   *fcgi_server;
 	char            *request, *method, *uri, *path_info, *vars, *http_version, *body, *file_on_disk;
 	long            header_length, content_length, buffer_size, bytes_in_buffer;
-#ifdef HAVE_REWRITE
+	t_req_method    request_method;
 	char            *request_uri;
-#endif
 	int             uri_len;
 	bool            data_sent;
 	char            *local_user;
@@ -57,6 +56,7 @@ typedef struct type_session {
 	t_host          *host;
 	bool            host_copied;
 	char            *remote_user;
+	t_auth_method   http_auth;
 	t_directory     *directory;
 	bool            handling_error;
 	char            *reason_for_403;
@@ -65,7 +65,6 @@ typedef struct type_session {
 	int             return_code;
 	int             error_code;
 	t_tempdata      *tempdata;
-	bool            put_method;
 	char            *uploaded_file;
 	long            uploaded_size;
 
@@ -101,7 +100,7 @@ void init_session(t_session *session);
 void reset_session(t_session *session);
 void destroy_session(t_session *session);
 
-void set_403_reason(t_session *session, int reason);
+void determine_request_method(t_session *session);
 t_headerfield *parse_headerfields(char *line);
 char *get_headerfield(char *key, t_headerfield *headerfields);
 void remove_headerfields(t_session *session);
